#
# Conditional build:
%bcond_without	apidocs	# sphinx based documentation
%bcond_without	python3		# do not build python3 modules

%define		module	netaddr
Summary:	A pure Python network address representation and manipulation library
Name:		python-netaddr
Version:	0.7.19
Release:	7
License:	BSD
Group:		Development/Languages/Python
Source0:	https://pypi.python.org/packages/source/n/netaddr/%{module}-%{version}.tar.gz
# Source0-md5:	51019ef59c93f3979bcb37d3b8527e07
Patch0:		script-shebang.patch
URL:		https://github.com/drkjam/netaddr/
BuildRequires:	rpmbuild(macros) >= 1.710
BuildRequires:	python-modules
%{?with_python3:BuildRequires:	python3-modules}
BuildRequires:	rpm-pythonprov
%{?with_apidocs:BuildRequires:	sphinx-pdg}
BuildArch:	noarch
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
A pure Python network address representation and manipulation library.

netaddr provides a Pythonic way to work with:
- IPv4 and IPv6 addresses and subnets (including CIDR notation)
- MAC (Media Access Control) addresses in multiple presentation
  formats
- IEEE EUI-64, OUI and IAB identifiers
- nmap-style IP address ranges
- a user friendly IP glob-style format

Included are routines for:
- generating, sorting and summarizing IP addresses
- converting IP addresses and ranges between various different formats
- performing set based operations on groups of IP addresses and
  subnets
- arbitrary IP address range calculations and conversions
- querying IEEE OUI and IAB organisational information
- querying of IP standards related data from key IANA data sources

%package -n python3-netaddr
Summary:	A pure Python network address representation and manipulation library
Group:		Development/Languages/Python

%description -n python3-netaddr
A pure Python network address representation and manipulation library.

netaddr provides a Pythonic way to work with:
- IPv4 and IPv6 addresses and subnets (including CIDR notation)
- MAC (Media Access Control) addresses in multiple presentation
  formats
- IEEE EUI-64, OUI and IAB identifiers
- nmap-style IP address ranges
- a user friendly IP glob-style format

Included are routines for:
- generating, sorting and summarizing IP addresses
- converting IP addresses and ranges between various different formats
- performing set based operations on groups of IP addresses and
  subnets
- arbitrary IP address range calculations and conversions
- querying IEEE OUI and IAB organisational information
- querying of IP standards related data from key IANA data sources

%package -n netaddr
Summary:	An interactive shell for the Python netaddr library
Group:		Development/Languages/Python
%if %{with python3}
Requires:	python3-netaddr = %{version}-%{release}
%else
Requires:	%{name} = %{version}-%{release}
%endif

%description -n netaddr
Interactive shell for the python-netaddr library.

%prep
%setup -q -n %{module}-%{version}
%patch0 -p1

%{__sed} -i -e '1s,/usr/bin/env python,%{?with_python3:%{__python3}}%{!?with_python3:%{__python}},' \
	netaddr/tools/netaddr

%build
%py_build

%if %{with python3}
%py3_build
%endif

%install
rm -rf $RPM_BUILD_ROOT
%py_install \
	--optimize 2 \
	--root=$RPM_BUILD_ROOT

%py_ocomp $RPM_BUILD_ROOT%{py_sitescriptdir}
%py_comp $RPM_BUILD_ROOT%{py_sitescriptdir}
%py_postclean

%if %{with apidocs}
sphinx-build -b html -d build/doctrees -D latex_paper_size=a4 docs/source build/html
%endif

%if %{with python3}
# Remove python2 artefacts
%{__rm} -f $RPM_BUILD_ROOT%{_bindir}/*
%py3_install \
	--optimize 2 \
	--root=$RPM_BUILD_ROOT
%py3_ocomp $RPM_BUILD_ROOT%{py_sitescriptdir}
%py3_comp $RPM_BUILD_ROOT%{py_sitescriptdir}
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc AUTHORS CHANGELOG README.md
%if %{with apidocs}
%doc build/html
%endif
%{py_sitescriptdir}/*.egg-info
%dir %{py_sitescriptdir}/%{module}
%{py_sitescriptdir}/%{module}/*.py[co]
%dir %{py_sitescriptdir}/%{module}/contrib
%{py_sitescriptdir}/%{module}/contrib/*.py[co]
%dir %{py_sitescriptdir}/%{module}/eui
%{py_sitescriptdir}/%{module}/eui/*.py[co]
%{py_sitescriptdir}/%{module}/eui/*.idx
%{py_sitescriptdir}/%{module}/eui/*.txt
%dir %{py_sitescriptdir}/%{module}/ip
%{py_sitescriptdir}/%{module}/ip/*.py[co]
%{py_sitescriptdir}/%{module}/ip/*.xml
%dir %{py_sitescriptdir}/%{module}/strategy
%{py_sitescriptdir}/%{module}/strategy/*.py[co]
#%dir %{py_sitescriptdir}/%{module}/tests
#%{py_sitescriptdir}/%{module}/tests/*.py[co]
#%{py_sitescriptdir}/%{module}/tests/2.x/core
#%{py_sitescriptdir}/%{module}/tests/2.x/eui
#%{py_sitescriptdir}/%{module}/tests/2.x/ip
#%{py_sitescriptdir}/%{module}/tests/2.x/strategy

%if %{with python3}
%files -n python3-netaddr
%defattr(644,root,root,755)
%doc AUTHORS CHANGELOG README.md
%if %{with apidocs}
%doc build/html
%endif
%{py3_sitescriptdir}/*.egg-info
%dir %{py3_sitescriptdir}/%{module}
%{py3_sitescriptdir}/%{module}/*.py
%{py3_sitescriptdir}/%{module}/__pycache__
%dir %{py3_sitescriptdir}/%{module}/contrib
%{py3_sitescriptdir}/%{module}/contrib/*.py
%{py3_sitescriptdir}/%{module}/contrib/__pycache__
%dir %{py3_sitescriptdir}/%{module}/eui
%{py3_sitescriptdir}/%{module}/eui/*.py
%{py3_sitescriptdir}/%{module}/eui/__pycache__
%{py3_sitescriptdir}/%{module}/eui/*.idx
%{py3_sitescriptdir}/%{module}/eui/*.txt
%dir %{py3_sitescriptdir}/%{module}/ip
%{py3_sitescriptdir}/%{module}/ip/*.py
%{py3_sitescriptdir}/%{module}/ip/__pycache__
%{py3_sitescriptdir}/%{module}/ip/*.xml
%dir %{py3_sitescriptdir}/%{module}/strategy
%{py3_sitescriptdir}/%{module}/strategy/*.py
%{py3_sitescriptdir}/%{module}/strategy/__pycache__
#%dir %{py3_sitescriptdir}/%{module}/tests
#%{py3_sitescriptdir}/%{module}/tests/*.py
#%{py3_sitescriptdir}/%{module}/tests/__pycache__
#%{py3_sitescriptdir}/%{module}/tests/3.x/core
#%{py3_sitescriptdir}/%{module}/tests/3.x/eui
#%{py3_sitescriptdir}/%{module}/tests/3.x/ip
#%{py3_sitescriptdir}/%{module}/tests/3.x/strategy
%endif

%files -n netaddr
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/netaddr
%changelog
* Sun Apr 10 2022 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/python-netaddr.git;a=log;h=master

* Sun Apr 10 2022 Jan Rękorajski <baggins@pld-linux.org> 2b41b2a
- make sure python3 script is installed, rel 7

* Wed Mar 30 2022 Jan Rękorajski <baggins@pld-linux.org> f29875c
- rebuild with tests and docs

* Sat Mar 26 2022 Jan Rękorajski <baggins@pld-linux.org> 5d2e9ef
- rebuild with python 3.10

* Fri Mar 25 2022 Jan Rękorajski <baggins@pld-linux.org> b57b7a1
- rebuild with python 3.10

* Sat Mar 06 2021 Jan Palus <atler@pld-linux.org> 390271c
- fix shebang; use python3 in bin by default; rel 3

* Mon Oct 28 2019 Jan Rękorajski <baggins@pld-linux.org> 6066b9f
- rebuild with python 3.8
- release 2 (by relup.sh)

* Sat Jul 07 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> ca4d4c7
- up to 0.7.19

* Mon Jul 02 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> cdb68b8
- release 6 (by relup.sh)

* Thu Dec 29 2016 Arkadiusz Miśkiewicz <arekm@maven.pl> 8c64715
- python 3.6
- release 5 (by relup.sh)

* Sun Nov 29 2015 Jacek Konieczny <jajcus@jajcus.net> 7400cab
- BR: rpmbuild(macros) >= 1.710

* Sat Nov 28 2015 Jacek Konieczny <jajcus@jajcus.net> b9de10a
- release 4 (by relup.sh)

* Sat Nov 28 2015 Jacek Konieczny <jajcus@jajcus.net> 7b967b9
- automatic change: use py_build/py_install macros

* Mon Sep 14 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> 0feb76a
- python3.5 rebuild
- release 3 (by relup.sh)

* Sun Sep 13 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> 21bee07
- python 3.5 rebuild
- release 2 (by relup.sh)

* Tue Jun 16 2015 Jacek Konieczny <j.konieczny@eggsoft.pl> 0b29eab
- Version: 0.7.14, sphinx-generated docs

* Sun Oct 19 2014 Arkadiusz Miśkiewicz <arekm@maven.pl> 1813b84
- python 3.4
- release 5 (by relup.sh)

* Wed Nov 14 2012 Arkadiusz Miśkiewicz <arekm@maven.pl> 054f98a
- release 4 (by relup.sh)

* Sat Oct 01 2011 Elan Ruusamäe <glen@pld-linux.org> 009884d
- add invalid netaddr patch from fedora

* Fri Jul 15 2011 Jacek Konieczny <jajcus@pld-linux.org> df012ee
- Python 3.2 fixes
- Release: 2

* Sun Jun 12 2011 Jacek Konieczny <jajcus@pld-linux.org> 2249595
- Version: 0.7.5
- new URL and Source URL
- python3- package added
- /usr/bin/netaddr moved to a separate package

